==> taxware-all-electric-contract-1.0.5-20230718.040027-30-sources.jar: com/xforceplus/taxware/contract/allelectric/message/GetSupportServiceMessage.java <==
package com.xforceplus.taxware.contract.allelectric.message;

import com.xforceplus.taxware.architecture.g1.domain.contract.BaseRestfulParameterDTO;
import com.xforceplus.taxware.contract.allelectric.message.common.PageInfoResponse;
import lombok.Data;
import lombok.EqualsAndHashCode;

import java.util.ArrayList;
import java.util.List;

/**
 * 计费服务查询
 * <p>
 * https://api-mock.xforceplus.com/project/141/interface/api/41448
 */
public class GetSupportServiceMessage {

    @Data
    @EqualsAndHashCode(callSuper = true)
    public static class Parameter extends BaseRestfulParameterDTO {

        /**
         * 租户id
         */
        private String tenantId;

        /**
         * 税号
         */
        private String taxNo;

        /**
         * 服务名称(支持查询多个，以英文逗号分隔)
         */
        private String serviceNames;

        /**
         * 服务状态（enable：启用 disabled：停用，不传查询所有状态）
         */
        private String serviceStatus;

        /**
         * 当前页码
         */
        private Integer pageNo = 1;

        /**
         * 每页数量
         */
        private Integer pageSize = 100;
    }

    @Data
    public static class Response {

        /**
         * 返回码（1为成功 其余为失败）
         */
        private String code = "1";

        /**
         * 返回信息
         */
        private String message = "成功";

        /**
         * 追踪码
         */
        private String traceId;
        private Result result = new Result();

        @Data
        public static class Result {

            /**
             * 租户列表
             */
            private List<TenantDto> tenantList = new ArrayList<>();

            /**
             * 分页信息
             */
            private PageInfoResponse pageInfo;

            @Data
            public static class TenantDto {

                /**
                 * 租户ID
                 */
                private String tenantId;

                /**
                 * 税号
                 */
                private String taxNo;

                /**
                 * 公司名称
                 */
                private String companyName;

                /**
                 * 服务列表
                 */
                private List<SupportServiceDto> serviceList;

                @Data
                public static class SupportServiceDto {

                    /**
                     * 服务类型(tax:税控 ae:全电)
                     */
                    private List<String> serviceTypeList;

                    /**
                     * 服务名称
                     */
                    private String serviceName;

                    /**
                     * 服务开通时间(格式:yyyy-MM-dd HH:mm:ss.SSS)
                     */
                    private String enabledTime;

                    /**
                     * 服务关闭时间（格式:yyyy-MM-dd HH:mm:ss.SSS）
                     */
                    private String disabledTime;

                    /**
                     * 创建人
                     */
                    private String createdBy;
                }
            }
        }

    }

    /**
     * 开票（make）
     * 认证（authentication）
     * 验真（verification）
     * 抽取（assistant）
     * 低频同步（bravetroops）
     * 红字信息表申请（rnfnApply）
     * 红字信息表同步（rnfnDownload）
     * 发票归集（collection）
     */
    public enum ServiceNameEnum {
        MAKE("make"),
        AUTHENTICATION("authentication"),
        VERIFICATION("verification"),
        ASSISTANT("assistant"),
        BRAVETROOPS("bravetroops"),
        RNFN_APPLY("rnfnApply"),
        RNFN_DOWNLOAD("rnfnDownload"),
        COLLECTION("collection");

        private final String name;

        ServiceNameEnum(String name) {
            this.name = name;
        }

        public String getName() {
            return name;
        }
    }
}

==> taxware-all-electric-contract-1.0.6-20230915.034802-13-sources.jar: com/xforceplus/taxware/contract/allelectric/message/GetSupportServiceMessage.java <==
package com.xforceplus.taxware.contract.allelectric.message;

import com.xforceplus.taxware.architecture.g1.domain.contract.BaseRestfulParameterDTO;
import com.xforceplus.taxware.contract.allelectric.message.common.PageInfoResponse;
import lombok.Data;
import lombok.EqualsAndHashCode;

import java.util.ArrayList;
import java.util.List;

/**
 * 计费服务查询
 * <p>
 * https://api-mock.xforceplus.com/project/141/interface/api/41448
 */
public class GetSupportServiceMessage {

    @Data
    @EqualsAndHashCode(callSuper = true)
    public static class Parameter extends BaseRestfulParameterDTO {

        /**
         * 租户id
         */
        private String tenantId;

        /**
         * 税号
         */
        private String taxNo;

        /**
         * 服务名称(支持查询多个，以英文逗号分隔)
         */
        private String serviceNames;

        /**
         * 当前页码
         */
        private Integer pageNo = 1;

        /**
         * 每页数量
         */
        private Integer pageSize = 100;
    }

    @Data
    public static class Response {

        /**
         * 返回码（1为成功 其余为失败）
         */
        private String code = "1";

        /**
         * 返回信息
         */
        private String message = "成功";

        /**
         * 追踪码
         */
        private String traceId;

        /**
         * 结果
         */
        private Result result = new Result();

        @Data
        public static class Result {

            /**
             * 租户列表
             */
            private List<TenantDto> tenantList = new ArrayList<>();

            /**
             * 分页信息
             */
            private PageInfoResponse pageInfo;

            @Data
            public static class TenantDto {

                /**
                 * 租户ID
                 */
                private String tenantId;

                /**
                 * 税号
                 */
                private String taxNo;

                /**
                 * 公司名称
                 */
                private String companyName;

                /**
                 * 服务列表
                 */
                private List<String> serviceNameList;

            }
        }

    }

}
